pub struct Delete;Expand description
Deletes the selected text or the character before the cursor.
- If there is a non-empty selection, deletes the selection.
- If there is no selection, deletes the previous character.
- If the cursor is after indentation only, deletes the entire indentation.