Duplicate

Struct Duplicate 

pub struct Duplicate;
Duplicates the selected text or the current line if no selection exists.

If there is a selection, it duplicates the selected text immediately after it. If there is no selection, it duplicates the entire line under the cursor, preserving the cursor’s relative column position.