pub struct Indent;Expand description
Inserts indentation at the beginning of the current line or selected lines.
- If there is a selection, inserts indentation at the start of each selected line.
- If there is no selection, inserts indentation at the current line.
- Updates cursor and selection accordingly.