pub struct InsertNewline;Expand description
Inserts a newline at the cursor with automatic indentation.
The indentation is computed based on the current line and column.
Delegates the actual insertion to InsertText.