MoveDown

Struct MoveDown 

pub struct MoveDown {
    pub shift: bool,
}
Moves the cursor one line down.

If the next line is shorter, the cursor is placed at the end of that line. If shift is true, the selection is extended to the new cursor position. If shift is false, the selection is cleared.

Fields

shift: bool