MoveLeft

Struct MoveLeft 

pub struct MoveLeft {
    pub shift: bool,
}
Moves the cursor one character to the left.

If shift is true, the selection is extended to the new cursor position. If shift is false and there is an active selection, the cursor jumps to the start of the selection and the selection is cleared. Otherwise, the cursor moves one position to the left.

Fields

shift: bool