pub struct Paste;Expand description
Pastes text from the clipboard at the current cursor position.
If a selection exists, it will be replaced by the pasted text. The pasted text is adjusted using language-specific indentation rules.