pub struct ToggleComment;Trait Implementations
Sourceimpl Action for ToggleComment
impl Action for ToggleComment
Sourcefn apply(&mut self, editor: &mut Editor)
fn apply(&mut self, editor: &mut Editor)
The ToggleComment action toggles line comments at the start of the selected lines.
If all lines in the selection already start with the language’s comment string (e.g., “//” for Rust), this action removes the comment string from each affected line. Otherwise, it prepends the comment string to the beginning of each line in the selection.
If there is no selection, the action is applied to the line under the cursor.