pub struct UnIndent;Expand description
Removes one indentation level from the start of the current line or selected lines.
- If there is a selection, removes indentation from each selected line.
- If there is no selection, removes indentation from the current line.
- Updates cursor and selection accordingly.