Module code

Module code 

Structs

ChunksBytes
An iterator over byte slices of Rope chunks. This is used to feed tree-sitter without allocating a full String.
Code
Edit
EditBatch
EditState
RopeGraphemes
An implementation of a graphemes iterator, for iterating over the graphemes of a RopeSlice.
RopeProvider
A lightweight wrapper around a RopeSlice that implements tree_sitter::TextProvider. This allows using tree-sitter’s QueryCursor::matches directly on a Rope without converting it to a String.

Enums

Operation

Functions

grapheme_width
grapheme_width_and_bytes_len
grapheme_width_and_chars_len