pub struct MoveRight {
pub shift: bool,
}Expand description
Moves the cursor one character to the right.
If shift is true, the selection is extended to the new cursor position.
If shift is false and there is an active selection, the cursor jumps
to the end of the selection and the selection is cleared.
Otherwise, the cursor moves one position to the right.
Fields
shift: boolTrait Implementations